@@ -1,12 +1,15 @@
 import os
-import random
 from typing import Dict, Union, List
+
 from elasticsearch import Elasticsearch, NotFoundError
+
+from deep_utils.utils.json_utils.json_utils import JsonUtils
 from deep_utils.utils.logging_utils.logging_utils import value_error_log
-from deep_utils.utils.json_utils.json_utils import dump_json
+
+from deep_utils.elasticsearch.search_engine.abs_elasticsearch_search_engine import ElasticSearchABS
 
 
-class ElasticsearchEngin:
+class ElasticsearchEngin(ElasticSearchABS):
     def __init__(self, elastic_url="http://localhost:9200", es=None, timeout=10, logger=None, verbose=1):
         if es is None:
             self.es = Elasticsearch(elastic_url, timeout=timeout)
@@ -112,7 +115,7 @@ class ElasticsearchEngin:
             province = value['province_name']
             city_name = value['name']
             os.makedirs("equals", exist_ok=True)
-            dump_json(f"equals/{province}_{city_name}.json", hits, ensure_ascii=False)
+            JsonUtils.dump_json(f"equals/{province}_{city_name}.json", hits, ensure_ascii=False)
             print(f"There are two objects with the same characteristics with the same name, {hits}")
             hits = [hits[0]]
 
@@ -129,9 +132,7 @@ class ElasticsearchEngin:
 
     @staticmethod
     def term_search(es_client, field_term_dict: dict, index_name: str):
-
         query = ElasticsearchEngin.get_bool_must_constant_score_query(field_term_dict)
-
         results = es_client.search(index=index_name, query=query)
         return results.body
 
@@ -170,25 +171,7 @@ class ElasticsearchEngin:
             sort = []
         return sort
 
-    @staticmethod
-    def get_bool_must_constant_score_query(field_term_dict: dict):
-        must_list = []
-        for field, term in field_term_dict.items():
-            if term is None:
-                continue
-            inner_query = {
-                "constant_score": {
-                    "filter": {
-                        "term": {
-                            field: term
-                        }
-                    }
-                }
-            }
-            must_list.append(inner_query)
 
-        query = {"bool": {"must": must_list}}
-        return query
 
     @staticmethod
     def get_bool_must_fuzzy_query(field_term_dict: Dict[str, str]):
@@ -385,18 +368,6 @@ class ElasticsearchEngin:
         hits = ElasticsearchEngin.get_hits(results)
         return hits
 
-    @staticmethod
-    def get_hits(results):
-        """
-        This is a simple method to extract hits or return none when the output of the search has no hits
-        :param results:
-        :return:
-        """
-        hits = results['hits']['hits']
-        if len(hits) == 0:
-            hits = None
-        return hits
-
     def search_bool_must_fuzzy_query_geo_sort(self,
                                               field_term_dict: dict,
                                               index_name: str,
@@ -507,37 +478,29 @@ class ElasticsearchEngin:
         hits = ElasticsearchEngin.get_hits(results)
         return hits
 
-    @staticmethod
-    def get_match_query(field_name="",
-                        field_value="",
-                        keyword="match",
-                        ):
+    def search_match_query(self, index_name, field_name="", field_value="", keyword="match", size=None,
+                           return_source: bool = False):
         """
-        This function is used to get query-match. It will simply return query-match json
+        A simple match search
+        {
+        "query": {
+            "keyword": {
+                "field_name": "field_value"
+                     }
+                 }
+         }
+        :param index_name:
         :param field_name:
         :param field_value:
         :param keyword:
+        :param size:
+        :param return_source:
         :return:
+
         """
-        if keyword == "match":
-
-            query = {
-                keyword: {
-                    field_name: field_value
-                }
-            }
-        elif keyword == "match_all":
-            query = {
-                keyword: {}
-            }
-        else:
-            raise ValueError(f"keyword: {keyword} is not valid!")
-        return query
-
-    def search_match_query(self, index_name, field_name="", field_value="", keyword="match", size=None):
         query = self.get_match_query(field_name=field_name, field_value=field_value, keyword=keyword)
         results = self.es.search(index=index_name, query=query, size=size).body
-        hits = ElasticsearchEngin.get_hits(results)
+        hits = ElasticsearchEngin.get_hits(results, return_source=return_source)
         return hits
 
     def search_by_id(self, index_name, id_value, id_field_name="_id") -> Union[dict, None]:
